# jgtml
JGTML - Trading Machine-Learning

* primarily designed to analyze the effectiveness of trading signals
* designed to analyze the effectiveness of trading signals within the context of larger balance lines.
* immediate goal : creating an efficient trading assistance system that helps manage the lifecycle of trades from entry orders through exit strategies


----



CLI's HELP
_____

## SEE: [CLI_HELP.md](CLI_HELP.md)

